@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,22 +13,25 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions # type: ignore
-from google.api_core import exceptions                 # type: ignore
-from google.api_core import gapic_v1                   # type: ignore
-from google.api_core import retry as retries           # type: ignore
-from google.auth import credentials                    # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials   # type: ignore
 from google.oauth2 import service_account              # type: ignore
 
-from oceanbolt.com.entities_v3.types import service
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from oceanbolt.com.entities_v3.types import service
 from .transports.base import EntityServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import EntityServiceGrpcAsyncIOTransport
 from .client import EntityServiceClient
@@ -45,26 +47,85 @@ class EntityServiceAsyncClient:
 
     common_billing_account_path = staticmethod(EntityServiceClient.common_billing_account_path)
     parse_common_billing_account_path = staticmethod(EntityServiceClient.parse_common_billing_account_path)
-
     common_folder_path = staticmethod(EntityServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(EntityServiceClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(EntityServiceClient.common_organization_path)
     parse_common_organization_path = staticmethod(EntityServiceClient.parse_common_organization_path)
-
     common_project_path = staticmethod(EntityServiceClient.common_project_path)
     parse_common_project_path = staticmethod(EntityServiceClient.parse_common_project_path)
-
     common_location_path = staticmethod(EntityServiceClient.common_location_path)
     parse_common_location_path = staticmethod(EntityServiceClient.parse_common_location_path)
 
-    from_service_account_info = EntityServiceClient.from_service_account_info
-    from_service_account_file = EntityServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            EntityServiceAsyncClient: The constructed client.
+        """
+        return EntityServiceClient.from_service_account_info.__func__(EntityServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            EntityServiceAsyncClient: The constructed client.
+        """
+        return EntityServiceClient.from_service_account_file.__func__(EntityServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[ClientOptions] = None):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return EntityServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> EntityServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             EntityServiceTransport: The transport used by the client instance.
@@ -74,12 +135,12 @@ class EntityServiceAsyncClient:
     get_transport_class = functools.partial(type(EntityServiceClient).get_transport_class, type(EntityServiceClient))
 
     def __init__(self, *,
-            credentials: credentials.Credentials = None,
-            transport: Union[str, EntityServiceTransport] = 'grpc_asyncio',
+            credentials: ga_credentials.Credentials = None,
+            transport: Union[str, EntityServiceTransport] = "grpc_asyncio",
             client_options: ClientOptions = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
-        """Instantiate the entity service client.
+        """Instantiates the entity service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -111,7 +172,6 @@ class EntityServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = EntityServiceClient(
             credentials=credentials,
             transport=transport,
@@ -121,18 +181,35 @@ class EntityServiceAsyncClient:
         )
 
     async def list_segments(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListSegmentsResponse:
         r"""ListSegments retrieves all available vessel segments
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_segments():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_segments(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -144,7 +221,6 @@ class EntityServiceAsyncClient:
                 ListSegments
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -167,18 +243,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_zones(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListTonnageZonesResponse:
         r"""ListZones retrieves all zones
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_zones():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_zones(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -190,7 +283,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -213,19 +305,37 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_zones_with_polygons(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListTonnageZonesWithPolygonsResponse:
         r"""ListZonesWithPolygons retrieves all zones with
         Polygons
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import entities_v3
+
+            def sample_list_zones_with_polygons():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_zones_with_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -237,7 +347,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -260,18 +369,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_regions(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListRegionsResponse:
         r"""ListRegions retrives all regions
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_regions():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_regions(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -283,7 +409,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -306,18 +431,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_commodities(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListCommoditiesResponse:
         r"""ListCommodities retrives all commodities
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_commodities():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_commodities(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -329,7 +471,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -352,18 +493,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_countries(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListCountriesResponse:
         r"""ListCountries retrives all countries
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_countries():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_countries(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -375,7 +533,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -398,19 +555,37 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_regions_with_polygons(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListRegionsWithPolygonResponse:
         r"""ListRegionsWithPolygons retrives all regions with geo
         polygons
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import entities_v3
+
+            def sample_list_regions_with_polygons():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_regions_with_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -422,7 +597,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -445,18 +619,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def list_ports(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListPortsResponse:
         r"""ListPorts retrieves all ports
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_ports():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_ports(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -468,7 +659,6 @@ class EntityServiceAsyncClient:
                 List Ports
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -491,18 +681,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def search_polygons(self,
-            request: service.SearchRequest = None,
+            request: Union[service.SearchRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.SearchPolygonsResponse:
         r"""
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.SearchRequest`):
-                The request object. Search
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_search_polygons():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.SearchRequest(
+                )
+
+                # Make the request
+                response = client.search_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.SearchRequest, dict]):
+                The request object. Search
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -514,7 +721,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.SearchRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -537,18 +743,35 @@ class EntityServiceAsyncClient:
         return response
 
     async def search_vessels(self,
-            request: service.SearchRequest = None,
+            request: Union[service.SearchRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.SearchVesselsResponse:
         r"""
 
-        Args:
-            request (:class:`oceanbolt.com.entities_v3.types.SearchRequest`):
-                The request object. Search
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_search_vessels():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.SearchRequest(
+                )
+
+                # Make the request
+                response = client.search_vessels(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.SearchRequest, dict]):
+                The request object. Search
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -560,7 +783,6 @@ class EntityServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.SearchRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -582,16 +804,16 @@ class EntityServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
 
-
-
-
-
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            'oceanbolt-com-entities',
+            "oceanbolt-com-entities",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
@@ -599,5 +821,5 @@ except pkg_resources.DistributionNotFound:
 
 
 __all__ = (
-    'EntityServiceAsyncClient',
+    "EntityServiceAsyncClient",
 )
