@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,26 +13,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions                            # type: ignore
-from google.api_core import gapic_v1                              # type: ignore
-from google.api_core import retry as retries                      # type: ignore
-from google.auth import credentials                               # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials             # type: ignore
 from google.auth.transport import mtls                            # type: ignore
 from google.auth.transport.grpc import SslCredentials             # type: ignore
 from google.auth.exceptions import MutualTLSChannelError          # type: ignore
 from google.oauth2 import service_account                         # type: ignore
 
-from oceanbolt.com.entities_v3.types import service
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from oceanbolt.com.entities_v3.types import service
 from .transports.base import EntityServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import EntityServiceGrpcTransport
 from .transports.grpc_asyncio import EntityServiceGrpcAsyncIOTransport
@@ -47,13 +48,13 @@ class EntityServiceClientMeta(type):
     objects.
     """
     _transport_registry = OrderedDict()  # type: Dict[str, Type[EntityServiceTransport]]
-    _transport_registry['grpc'] = EntityServiceGrpcTransport
-    _transport_registry['grpc_asyncio'] = EntityServiceGrpcAsyncIOTransport
+    _transport_registry["grpc"] = EntityServiceGrpcTransport
+    _transport_registry["grpc_asyncio"] = EntityServiceGrpcAsyncIOTransport
 
     def get_transport_class(cls,
             label: str = None,
         ) -> Type[EntityServiceTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -76,7 +77,8 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -103,14 +105,15 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         return api_endpoint.replace(".googleapis.com", ".mtls.googleapis.com")
 
-    DEFAULT_ENDPOINT = 'api.oceanbolt.com'
+    DEFAULT_ENDPOINT = "api.oceanbolt.com"
     DEFAULT_MTLS_ENDPOINT = _get_default_mtls_endpoint.__func__(  # type: ignore
         DEFAULT_ENDPOINT
     )
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -127,7 +130,7 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -140,23 +143,24 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         """
         credentials = service_account.Credentials.from_service_account_file(
             filename)
-        kwargs['credentials'] = credentials
+        kwargs["credentials"] = credentials
         return cls(*args, **kwargs)
 
     from_service_account_json = from_service_account_file
 
     @property
     def transport(self) -> EntityServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            EntityServiceTransport: The transport used by the client instance.
+            EntityServiceTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def common_billing_account_path(billing_account: str, ) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(billing_account=billing_account, )
 
     @staticmethod
@@ -167,7 +171,7 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str, ) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder, )
 
     @staticmethod
@@ -178,7 +182,7 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str, ) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization, )
 
     @staticmethod
@@ -189,7 +193,7 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
     @staticmethod
     def common_project_path(project: str, ) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project, )
 
     @staticmethod
@@ -200,7 +204,7 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str, ) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(project=project, location=location, )
 
     @staticmethod
@@ -209,13 +213,72 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[client_options_lib.ClientOptions] = None):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError("Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`")
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError("Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`")
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (use_mtls_endpoint == "auto" and client_cert_source):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(self, *,
-            credentials: Optional[credentials.Credentials] = None,
+            credentials: Optional[ga_credentials.Credentials] = None,
             transport: Union[str, EntityServiceTransport, None] = None,
             client_options: Optional[client_options_lib.ClientOptions] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
-        """Instantiate the entity service client.
+        """Instantiates the entity service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -257,50 +320,32 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(client_options)
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = mtls.default_client_cert_source() if is_mtls else None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError("client_options.api_key and credentials are mutually exclusive")
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, EntityServiceTransport):
             # transport is a EntityServiceTransport instance.
-            if credentials or client_options.credentials_file:
-                raise ValueError('When providing a transport instance, '
-                                 'provide its credentials directly.')
+            if credentials or client_options.credentials_file or api_key_value:
+                raise ValueError("When providing a transport instance, "
+                                 "provide its credentials directly.")
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(google.auth._default, "get_api_key_credentials"):
+                credentials = google.auth._default.get_api_key_credentials(api_key_value)
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -310,21 +355,39 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def list_segments(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListSegmentsResponse:
         r"""ListSegments retrieves all available vessel segments
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_segments():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_segments(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -336,7 +399,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
                 ListSegments
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -360,18 +422,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_zones(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListTonnageZonesResponse:
         r"""ListZones retrieves all zones
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_zones():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_zones(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -383,7 +462,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -407,19 +485,37 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_zones_with_polygons(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListTonnageZonesWithPolygonsResponse:
         r"""ListZonesWithPolygons retrieves all zones with
         Polygons
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import entities_v3
+
+            def sample_list_zones_with_polygons():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_zones_with_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -431,7 +527,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -455,18 +550,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_regions(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListRegionsResponse:
         r"""ListRegions retrives all regions
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_regions():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_regions(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -478,7 +590,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -502,18 +613,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_commodities(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListCommoditiesResponse:
         r"""ListCommodities retrives all commodities
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_commodities():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_commodities(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -525,7 +653,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -549,18 +676,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_countries(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListCountriesResponse:
         r"""ListCountries retrives all countries
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_countries():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_countries(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -572,7 +716,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -596,19 +739,37 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_regions_with_polygons(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListRegionsWithPolygonResponse:
         r"""ListRegionsWithPolygons retrives all regions with geo
         polygons
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import entities_v3
+
+            def sample_list_regions_with_polygons():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_regions_with_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -620,7 +781,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -644,18 +804,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def list_ports(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.ListPortsResponse:
         r"""ListPorts retrieves all ports
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.EmptyParams):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_list_ports():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_ports(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -667,7 +844,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
                 List Ports
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.EmptyParams.
         # There's no risk of modifying the input as we've already verified
@@ -691,18 +867,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def search_polygons(self,
-            request: service.SearchRequest = None,
+            request: Union[service.SearchRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.SearchPolygonsResponse:
         r"""
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.SearchRequest):
-                The request object. Search
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_search_polygons():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.SearchRequest(
+                )
+
+                # Make the request
+                response = client.search_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.SearchRequest, dict]):
+                The request object. Search
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -714,7 +907,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.SearchRequest.
         # There's no risk of modifying the input as we've already verified
@@ -738,18 +930,35 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         return response
 
     def search_vessels(self,
-            request: service.SearchRequest = None,
+            request: Union[service.SearchRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.SearchVesselsResponse:
         r"""
 
-        Args:
-            request (oceanbolt.com.entities_v3.types.SearchRequest):
-                The request object. Search
+        .. code-block:: python
 
+            from oceanbolt.com import entities_v3
+
+            def sample_search_vessels():
+                # Create a client
+                client = entities_v3.EntityServiceClient()
+
+                # Initialize request argument(s)
+                request = entities_v3.SearchRequest(
+                )
+
+                # Make the request
+                response = client.search_vessels(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.entities_v3.types.SearchRequest, dict]):
+                The request object. Search
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -761,7 +970,6 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a service.SearchRequest.
         # There's no risk of modifying the input as we've already verified
@@ -784,16 +992,25 @@ class EntityServiceClient(metaclass=EntityServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
 
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
 
-
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
 
 
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            'oceanbolt-com-entities',
+            "oceanbolt-com-entities",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
@@ -801,5 +1018,5 @@ except pkg_resources.DistributionNotFound:
 
 
 __all__ = (
-    'EntityServiceClient',
+    "EntityServiceClient",
 )
