@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,20 +13,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import abc
-import typing
+from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
 import pkg_resources
 
-from google import auth  # type: ignore
-from google.api_core import exceptions  # type: ignore
-from google.api_core import gapic_v1    # type: ignore
-from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+import google.api_core
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials  # type: ignore
+from google.oauth2 import service_account # type: ignore
 
 from oceanbolt.com.entities_v3.types import service
 
-
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
@@ -37,26 +36,30 @@ try:
 except pkg_resources.DistributionNotFound:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
+
 class EntityServiceTransport(abc.ABC):
     """Abstract transport class for EntityService."""
 
     AUTH_SCOPES = (
     )
 
+    DEFAULT_HOST: str = 'api.oceanbolt.com'
     def __init__(
             self, *,
-            host: str = 'api.oceanbolt.com',
-            credentials: credentials.Credentials = None,
-            credentials_file: typing.Optional[str] = None,
-            scopes: typing.Optional[typing.Sequence[str]] = AUTH_SCOPES,
-            quota_project_id: typing.Optional[str] = None,
+            host: str = DEFAULT_HOST,
+            credentials: ga_credentials.Credentials = None,
+            credentials_file: Optional[str] = None,
+            scopes: Optional[Sequence[str]] = None,
+            quota_project_id: Optional[str] = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
+            always_use_jwt_access: Optional[bool] = False,
             **kwargs,
             ) -> None:
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -65,41 +68,48 @@ class EntityServiceTransport(abc.ABC):
             credentials_file (Optional[str]): A file with credentials that can
                 be loaded with :func:`google.auth.load_credentials_from_file`.
                 This argument is mutually exclusive with credentials.
-            scope (Optional[Sequence[str]]): A list of scopes.
+            scopes (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
+            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
+                be used for service account credentials.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ':' not in host:
             host += ':443'
         self._host = host
 
+        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}
+
+        # Save the scopes.
+        self._scopes = scopes
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
-            raise exceptions.DuplicateCredentialArgs("'credentials_file' and 'credentials' are mutually exclusive")
+            raise core_exceptions.DuplicateCredentialArgs("'credentials_file' and 'credentials' are mutually exclusive")
 
         if credentials_file is not None:
-            credentials, _ = auth.load_credentials_from_file(
+            credentials, _ = google.auth.load_credentials_from_file(
                                 credentials_file,
-                                scopes=scopes,
+                                **scopes_kwargs,
                                 quota_project_id=quota_project_id
                             )
-
         elif credentials is None:
-            credentials, _ = auth.default(scopes=scopes, quota_project_id=quota_project_id)
+            credentials, _ = google.auth.default(**scopes_kwargs, quota_project_id=quota_project_id)
+
+        # If the credentials are service account credentials, then always try to use self signed JWT.
+        if always_use_jwt_access and isinstance(credentials, service_account.Credentials) and hasattr(service_account.Credentials, "with_always_use_jwt_access"):
+            credentials = credentials.with_always_use_jwt_access(True)
 
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -153,96 +163,104 @@ class EntityServiceTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+         }
 
-        }
+    def close(self):
+        """Closes resources associated with the transport.
+
+       .. warning::
+            Only call this method if the transport is NOT shared
+            with other clients - this may cause errors in other clients!
+        """
+        raise NotImplementedError()
 
     @property
-    def list_segments(self) -> typing.Callable[
+    def list_segments(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListSegmentsResponse,
-                typing.Awaitable[service.ListSegmentsResponse]
+                Awaitable[service.ListSegmentsResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_zones(self) -> typing.Callable[
+    def list_zones(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListTonnageZonesResponse,
-                typing.Awaitable[service.ListTonnageZonesResponse]
+                Awaitable[service.ListTonnageZonesResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_zones_with_polygons(self) -> typing.Callable[
+    def list_zones_with_polygons(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListTonnageZonesWithPolygonsResponse,
-                typing.Awaitable[service.ListTonnageZonesWithPolygonsResponse]
+                Awaitable[service.ListTonnageZonesWithPolygonsResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_regions(self) -> typing.Callable[
+    def list_regions(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListRegionsResponse,
-                typing.Awaitable[service.ListRegionsResponse]
+                Awaitable[service.ListRegionsResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_commodities(self) -> typing.Callable[
+    def list_commodities(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListCommoditiesResponse,
-                typing.Awaitable[service.ListCommoditiesResponse]
+                Awaitable[service.ListCommoditiesResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_countries(self) -> typing.Callable[
+    def list_countries(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListCountriesResponse,
-                typing.Awaitable[service.ListCountriesResponse]
+                Awaitable[service.ListCountriesResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_regions_with_polygons(self) -> typing.Callable[
+    def list_regions_with_polygons(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListRegionsWithPolygonResponse,
-                typing.Awaitable[service.ListRegionsWithPolygonResponse]
+                Awaitable[service.ListRegionsWithPolygonResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def list_ports(self) -> typing.Callable[
+    def list_ports(self) -> Callable[
             [service.EmptyParams],
-            typing.Union[
+            Union[
                 service.ListPortsResponse,
-                typing.Awaitable[service.ListPortsResponse]
+                Awaitable[service.ListPortsResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def search_polygons(self) -> typing.Callable[
+    def search_polygons(self) -> Callable[
             [service.SearchRequest],
-            typing.Union[
+            Union[
                 service.SearchPolygonsResponse,
-                typing.Awaitable[service.SearchPolygonsResponse]
+                Awaitable[service.SearchPolygonsResponse]
             ]]:
         raise NotImplementedError()
 
     @property
-    def search_vessels(self) -> typing.Callable[
+    def search_vessels(self) -> Callable[
             [service.SearchRequest],
-            typing.Union[
+            Union[
                 service.SearchVesselsResponse,
-                typing.Awaitable[service.SearchVesselsResponse]
+                Awaitable[service.SearchVesselsResponse]
             ]]:
         raise NotImplementedError()
 
