@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,26 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions # type: ignore
-from google.api_core import exceptions                 # type: ignore
-from google.api_core import gapic_v1                   # type: ignore
-from google.api_core import retry as retries           # type: ignore
-from google.auth import credentials                    # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
+from google.auth import credentials as ga_credentials   # type: ignore
 from google.oauth2 import service_account              # type: ignore
 
-from google.protobuf import wrappers_pb2 as wrappers  # type: ignore
-from oceanbolt.com.polygonmanagement_v3.types import service
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
+from google.protobuf import wrappers_pb2  # type: ignore
+from oceanbolt.com.polygonmanagement_v3.types import service
 from .transports.base import PolygonManagementServiceTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import PolygonManagementServiceGrpcAsyncIOTransport
 from .client import PolygonManagementServiceClient
@@ -46,26 +48,85 @@ class PolygonManagementServiceAsyncClient:
 
     common_billing_account_path = staticmethod(PolygonManagementServiceClient.common_billing_account_path)
     parse_common_billing_account_path = staticmethod(PolygonManagementServiceClient.parse_common_billing_account_path)
-
     common_folder_path = staticmethod(PolygonManagementServiceClient.common_folder_path)
     parse_common_folder_path = staticmethod(PolygonManagementServiceClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(PolygonManagementServiceClient.common_organization_path)
     parse_common_organization_path = staticmethod(PolygonManagementServiceClient.parse_common_organization_path)
-
     common_project_path = staticmethod(PolygonManagementServiceClient.common_project_path)
     parse_common_project_path = staticmethod(PolygonManagementServiceClient.parse_common_project_path)
-
     common_location_path = staticmethod(PolygonManagementServiceClient.common_location_path)
     parse_common_location_path = staticmethod(PolygonManagementServiceClient.parse_common_location_path)
 
-    from_service_account_info = PolygonManagementServiceClient.from_service_account_info
-    from_service_account_file = PolygonManagementServiceClient.from_service_account_file
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            PolygonManagementServiceAsyncClient: The constructed client.
+        """
+        return PolygonManagementServiceClient.from_service_account_info.__func__(PolygonManagementServiceAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+            file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            PolygonManagementServiceAsyncClient: The constructed client.
+        """
+        return PolygonManagementServiceClient.from_service_account_file.__func__(PolygonManagementServiceAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(cls, client_options: Optional[ClientOptions] = None):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return PolygonManagementServiceClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> PolygonManagementServiceTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             PolygonManagementServiceTransport: The transport used by the client instance.
@@ -75,12 +136,12 @@ class PolygonManagementServiceAsyncClient:
     get_transport_class = functools.partial(type(PolygonManagementServiceClient).get_transport_class, type(PolygonManagementServiceClient))
 
     def __init__(self, *,
-            credentials: credentials.Credentials = None,
-            transport: Union[str, PolygonManagementServiceTransport] = 'grpc_asyncio',
+            credentials: ga_credentials.Credentials = None,
+            transport: Union[str, PolygonManagementServiceTransport] = "grpc_asyncio",
             client_options: ClientOptions = None,
             client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
             ) -> None:
-        """Instantiate the polygon management service client.
+        """Instantiates the polygon management service client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -112,7 +173,6 @@ class PolygonManagementServiceAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = PolygonManagementServiceClient(
             credentials=credentials,
             transport=transport,
@@ -122,18 +182,35 @@ class PolygonManagementServiceAsyncClient:
         )
 
     async def list_layers(self,
-            request: service.EmptyParams = None,
+            request: Union[service.EmptyParams, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Layers:
         r"""ListLayers lists layers for the current user
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.EmptyParams`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_list_layers():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.EmptyParams(
+                )
+
+                # Make the request
+                response = client.list_layers(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.EmptyParams, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -145,7 +222,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.EmptyParams(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -168,18 +244,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def create_layer(self,
-            request: service.CreateLayerRequest = None,
+            request: Union[service.CreateLayerRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Layer:
         r"""CreateLayer creates new layer for the current user
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.CreateLayerRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_create_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.CreateLayerRequest(
+                )
+
+                # Make the request
+                response = client.create_layer(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.CreateLayerRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -191,7 +284,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.CreateLayerRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -214,18 +306,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def delete_layer(self,
-            request: service.DeleteLayerRequest = None,
+            request: Union[service.DeleteLayerRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""DeleteLayer deletes layer for the current user
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.DeleteLayerRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_delete_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.DeleteLayerRequest(
+                )
+
+                # Make the request
+                response = client.delete_layer(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.DeleteLayerRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -237,7 +346,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.DeleteLayerRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -260,18 +368,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def describe_layer(self,
-            request: service.GetLayerRequest = None,
+            request: Union[service.GetLayerRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Layer:
         r"""GetLayer gets fleed by layer id for the current user
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.GetLayerRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_describe_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.GetLayerRequest(
+                )
+
+                # Make the request
+                response = client.describe_layer(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.GetLayerRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -283,7 +408,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.GetLayerRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -306,20 +430,38 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def rename_layer(self,
-            request: service.RenameLayerRequest = None,
+            request: Union[service.RenameLayerRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Layer:
         r"""RenameLayer changes the name of the layer for the
         current user
 
+
+        .. code-block:: python
+
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_rename_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.RenameLayerRequest(
+                )
+
+                # Make the request
+                response = client.rename_layer(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.RenameLayerRequest`):
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.RenameLayerRequest, dict]):
                 The request object.  LayerManagement requests ans
                 responses
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -331,7 +473,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.RenameLayerRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -354,19 +495,37 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def share_layer(self,
-            request: service.ShareLayerRequest = None,
+            request: Union[service.ShareLayerRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Layer:
         r"""Sets the shared status of the layer to be either
         shared/not shared
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.ShareLayerRequest`):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_share_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.ShareLayerRequest(
+                )
+
+                # Make the request
+                response = client.share_layer(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.ShareLayerRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -378,7 +537,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.ShareLayerRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -401,19 +559,37 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def unshare_layer(self,
-            request: service.ShareLayerRequest = None,
+            request: Union[service.ShareLayerRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Layer:
         r"""Sets the shared status of the layer to be either
         shared/not shared
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.ShareLayerRequest`):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_unshare_layer():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.ShareLayerRequest(
+                )
+
+                # Make the request
+                response = client.unshare_layer(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.ShareLayerRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -425,7 +601,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.ShareLayerRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -448,19 +623,37 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def list_polygons(self,
-            request: service.ListPolygonsRequest = None,
+            request: Union[service.ListPolygonsRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Polygons:
         r"""GetLayerPolygons gets layer polygons for the current
         user
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.ListPolygonsRequest`):
-                The request object.
 
+        .. code-block:: python
+
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_list_polygons():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.ListPolygonsRequest(
+                )
+
+                # Make the request
+                response = client.list_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.ListPolygonsRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -472,7 +665,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.ListPolygonsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -495,18 +687,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def add_polygon(self,
-            request: service.AddPolygonRequest = None,
+            request: Union[service.AddPolygonRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Polygon:
         r"""AddPolygon adds new vessel to user's layer
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.AddPolygonRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_add_polygon():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.AddPolygonRequest(
+                )
+
+                # Make the request
+                response = client.add_polygon(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.AddPolygonRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -518,7 +727,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.AddPolygonRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -541,18 +749,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def update_polygon(self,
-            request: service.UpdatePolygonRequest = None,
+            request: Union[service.UpdatePolygonRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.Polygon:
         r"""UpdatePolygon updates existing vessel to user's layer
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.UpdatePolygonRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_update_polygon():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.UpdatePolygonRequest(
+                )
+
+                # Make the request
+                response = client.update_polygon(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.UpdatePolygonRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -564,7 +789,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.UpdatePolygonRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -587,18 +811,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def delete_polygon(self,
-            request: service.DeletePolygonRequest = None,
+            request: Union[service.DeletePolygonRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""DeletePolygon removes vessel from user's layer
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.DeletePolygonRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_delete_polygon():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.DeletePolygonRequest(
+                )
+
+                # Make the request
+                response = client.delete_polygon(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.DeletePolygonRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -610,7 +851,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.DeletePolygonRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -633,18 +873,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def batch_add_polygons(self,
-            request: service.BatchPolygonsRequest = None,
+            request: Union[service.BatchPolygonsRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.BatchPolygonsRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_batch_add_polygons():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.BatchPolygonsRequest(
+                )
+
+                # Make the request
+                response = client.batch_add_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.BatchPolygonsRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -656,7 +913,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.BatchPolygonsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -679,18 +935,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def replace_polygons(self,
-            request: service.BatchPolygonsRequest = None,
+            request: Union[service.BatchPolygonsRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.BatchPolygonsRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_replace_polygons():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.BatchPolygonsRequest(
+                )
+
+                # Make the request
+                response = client.replace_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.BatchPolygonsRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -702,7 +975,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.BatchPolygonsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -725,18 +997,35 @@ class PolygonManagementServiceAsyncClient:
         return response
 
     async def drop_polygons(self,
-            request: service.DropPolygonsRequest = None,
+            request: Union[service.DropPolygonsRequest, dict] = None,
             *,
-            retry: retries.Retry = gapic_v1.method.DEFAULT,
+            retry: OptionalRetry = gapic_v1.method.DEFAULT,
             timeout: float = None,
             metadata: Sequence[Tuple[str, str]] = (),
             ) -> service.EmptyResponse:
         r"""
 
-        Args:
-            request (:class:`oceanbolt.com.polygonmanagement_v3.types.DropPolygonsRequest`):
-                The request object.
+        .. code-block:: python
 
+            from oceanbolt.com import polygonmanagement_v3
+
+            def sample_drop_polygons():
+                # Create a client
+                client = polygonmanagement_v3.PolygonManagementServiceClient()
+
+                # Initialize request argument(s)
+                request = polygonmanagement_v3.DropPolygonsRequest(
+                )
+
+                # Make the request
+                response = client.drop_polygons(request=request)
+
+                # Handle the response
+                print(response)
+
+        Args:
+            request (Union[oceanbolt.com.polygonmanagement_v3.types.DropPolygonsRequest, dict]):
+                The request object.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -748,7 +1037,6 @@ class PolygonManagementServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = service.DropPolygonsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -770,16 +1058,16 @@ class PolygonManagementServiceAsyncClient:
         # Done; return the response.
         return response
 
+    async def __aenter__(self):
+        return self
 
-
-
-
-
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            'oceanbolt-com-polygonmanagement',
+            "oceanbolt-com-polygonmanagement",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
@@ -787,5 +1075,5 @@ except pkg_resources.DistributionNotFound:
 
 
 __all__ = (
-    'PolygonManagementServiceAsyncClient',
+    "PolygonManagementServiceAsyncClient",
 )
